var files_dup =
[
    [ "array.h", "array_8h.html", "array_8h" ],
    [ "client.c", "client_8c.html", "client_8c" ],
    [ "client.h", "client_8h.html", "client_8h" ],
    [ "command.c", "command_8c.html", null ],
    [ "command.h", "command_8h.html", "command_8h" ],
    [ "control.c", "control_8c.html", "control_8c" ],
    [ "control.h", "control_8h.html", "control_8h" ],
    [ "core.c", "core_8c.html", "core_8c" ],
    [ "core.h", "core_8h.html", "core_8h" ],
    [ "data-loop.c", "data-loop_8c.html", "data-loop_8c" ],
    [ "data-loop.h", "data-loop_8h.html", "data-loop_8h" ],
    [ "factory.c", "factory_8c.html", "factory_8c" ],
    [ "factory.h", "factory_8h.html", "factory_8h" ],
    [ "global.c", "global_8c.html", "global_8c" ],
    [ "global.h", "global_8h.html", "global_8h" ],
    [ "interfaces.h", "interfaces_8h.html", "interfaces_8h" ],
    [ "introspect.c", "introspect_8c.html", "introspect_8c" ],
    [ "introspect.h", "introspect_8h.html", "introspect_8h" ],
    [ "link.c", "link_8c.html", "link_8c" ],
    [ "link.h", "link_8h.html", "link_8h" ],
    [ "log.c", "log_8c.html", "log_8c" ],
    [ "log.h", "log_8h.html", "log_8h" ],
    [ "loop.c", "loop_8c.html", "loop_8c" ],
    [ "loop.h", "loop_8h.html", "loop_8h" ],
    [ "main-loop.c", "main-loop_8c.html", "main-loop_8c" ],
    [ "main-loop.h", "main-loop_8h.html", "main-loop_8h" ],
    [ "map.h", "map_8h.html", "map_8h" ],
    [ "mem.c", "mem_8c.html", "mem_8c" ],
    [ "mem.h", "mem_8h.html", "mem_8h" ],
    [ "module.c", "module_8c.html", "module_8c" ],
    [ "module.h", "module_8h.html", "module_8h" ],
    [ "node.c", "node_8c.html", "node_8c" ],
    [ "node.h", "node_8h.html", "node_8h" ],
    [ "pipewire.c", "pipewire_8c.html", "pipewire_8c" ],
    [ "pipewire.h", "pipewire_8h.html", "pipewire_8h" ],
    [ "port.c", "port_8c.html", "port_8c" ],
    [ "port.h", "port_8h.html", "port_8h" ],
    [ "properties.c", "properties_8c.html", "properties_8c" ],
    [ "properties.h", "properties_8h.html", "properties_8h" ],
    [ "protocol.c", "protocol_8c.html", "protocol_8c" ],
    [ "protocol.h", "protocol_8h.html", "protocol_8h" ],
    [ "proxy.c", "proxy_8c.html", "proxy_8c" ],
    [ "proxy.h", "proxy_8h.html", "proxy_8h" ],
    [ "remote.c", "remote_8c.html", "remote_8c" ],
    [ "remote.h", "remote_8h.html", "remote_8h" ],
    [ "resource.c", "resource_8c.html", "resource_8c" ],
    [ "resource.h", "resource_8h.html", "resource_8h" ],
    [ "stream.c", "stream_8c.html", "stream_8c" ],
    [ "stream.h", "stream_8h.html", "stream_8h" ],
    [ "thread-loop.c", "thread-loop_8c.html", "thread-loop_8c" ],
    [ "thread-loop.h", "thread-loop_8h.html", "thread-loop_8h" ],
    [ "type.c", "type_8c.html", null ],
    [ "type.h", "type_8h.html", "type_8h" ],
    [ "utils.c", "utils_8c.html", null ],
    [ "utils.h", "utils_8h.html", "utils_8h" ],
    [ "work-queue.c", "work-queue_8c.html", null ],
    [ "work-queue.h", "work-queue_8h.html", "work-queue_8h" ]
];